@@ -17,12 +17,11 @@
 
 from __future__ import absolute_import
 
-from ..types import *
-from ..util import serialize
-from ..util import deserialize
+from ..types import Number, String, json
+from ..util import deserialize, serialize
 
 
-class Source(object):
+class Source:
 
     """Smartsheet Source data model."""
 
@@ -32,15 +31,10 @@ class Source(object):
         if base_obj is not None:
             self._base = base_obj
 
-        self.allowed_values = {
-            '_type': [
-                'sheet',
-                'template']}
+        self.allowed_values = {"_type": ["report", "sheet", "sight", "template"]}
 
         self._id_ = Number()
-        self._type_ = String(
-            accept=self.allowed_values['_type']
-        )
+        self._type_ = String(accept=self.allowed_values["_type"])
 
         if props:
             deserialize(self, props)
@@ -48,20 +42,20 @@ class Source(object):
         self.__initialized = True
 
     def __getattr__(self, key):
-        if key == 'id':
+        if key == "id":
             return self.id_
-        elif key == 'type':
+        elif key == "type":
             return self.type_
         else:
             raise AttributeError(key)
 
     def __setattr__(self, key, value):
-        if key == 'id':
+        if key == "id":
             self.id_ = value
-        elif key == 'type':
+        elif key == "type":
             self.type_ = value
         else:
-            super(Source, self).__setattr__(key, value)
+            super().__setattr__(key, value)
 
     @property
     def id_(self):
